Learn R Programming

amapro (version 0.1.4)

am.item: Add Item

Description

Add an item to a map

Usage

am.item(id, itype, ...)

Value

A map widget to plot, or to save and expand with more features

Arguments

id

A valid widget from am.init

itype

A string for item type name, like 'Marker'

...

attributes of item

Details

To add an item like Marker, Text or Polyline to the map

See Also

am.init code example

Examples

Run this code
if (interactive()) {
  am.init() |> am.item('Marker', position=c(116.6, 40))
}

Run the code above in your browser using DataLab