powered by
Add an item to a map
am.item(id, itype, ...)
A map widget to plot, or to save and expand with more features
A valid widget from am.init
A string for item type name, like 'Marker'
attributes of item
To add an item like Marker, Text or Polyline to the map
am.init code example
if (interactive()) { am.init() |> am.item('Marker', position=c(116.6, 40)) }
Run the code above in your browser using DataLab